.. _guide:

============
 User Guide
============

:Release: |version|

Guide for installing, configuring, and extending ``deux`` inside your
application.

.. toctree::
    :maxdepth: 1

    django
    usage
    extending
